import { View, Property } from '@nativescript/core';
export * from './view-helper';
/**
 * Custom view lifecycle for flavor integrations.
 */
export type CustomViewLifeCycle = {
    create: (id: string, component: any) => View;
    destroy: (id: string) => void;
};
export declare class SwiftUICommon extends View {
    static swiftUIEventEvent: string;
    data: any;
    swiftId: string;
}
export declare abstract class BaseUIDataDriver<ViewType extends SwiftUICommon = SwiftUICommon, DataType = unknown, ReceivedDataType = unknown> {
    protected owner: WeakRef<ViewType>;
    constructor(view: ViewType);
    updateData?(data: DataType): void;
    onEvent?(data: ReceivedDataType): void;
    abstract createNativeView(): UIView;
    registerEvents?(callback: (data: ReceivedDataType) => void): void;
    destroyNativeView?(): void;
}
export declare const dataProperty: Property<SwiftUICommon, any>;
export declare const swiftIdProperty: Property<SwiftUICommon, string>;
export interface NativeScriptWindowCommon {
    id: string;
    open(props?: any): Promise<void>;
    close(): Promise<void>;
    update(props?: any): Promise<void>;
}
export type SwiftUIComponentModifiers = Array<{
    [key: string]: any;
}>;
export type BaseSwiftUIComponentProps = {
    children?: Array<UIView>;
    modifiers?: SwiftUIComponentModifiers;
};
export declare class SwiftUIViewBase extends View {
    provider: UIViewController & any;
    props: BaseSwiftUIComponentProps & any;
    constructor();
    initNativeView(): void;
    initProps(props?: any): void;
    updateModifiers(modifiers: Array<{
        [key: string]: any;
    }>, force?: boolean): void;
    updateData(): void;
}
