import { View, Property, Utils } from '@nativescript/core';
export * from './view-helper';
export class SwiftUICommon extends View {
}
SwiftUICommon.swiftUIEventEvent = 'swiftUIEvent';
export class BaseUIDataDriver {
    constructor(view) {
        this.owner = new WeakRef(view);
    }
}
export const dataProperty = new Property({
    name: 'data',
});
dataProperty.register(SwiftUICommon);
export const swiftIdProperty = new Property({
    name: 'swiftId',
});
swiftIdProperty.register(SwiftUICommon);
const modifiersProperty = new Property({
    name: 'modifiers',
});
export class SwiftUIViewBase extends View {
    constructor() {
        super();
        this.props = {
            children: [],
            modifiers: []
        };
        this.initProps();
    }
    initNativeView() {
        this.provider.onEvent = (data) => {
            this.notify({
                eventName: 'onEvent',
                data: Utils.dataDeserialize(data),
            });
        };
        this.updateData();
    }
    initProps(props = {}) {
        this.props = {
            children: [],
            modifiers: [],
            ...props
        };
    }
    [modifiersProperty.setNative](value) {
        this.props.modifiers = value;
        this.updateData();
    }
    updateModifiers(modifiers, force) {
        if (force) {
            // just accept as-is, helps when duplicates are desired and order needs to be guaranteed
            this.props.modifiers = modifiers;
        }
        else {
            for (const modifier of modifiers) {
                const keys = Object.keys(modifier);
                for (const key of keys) {
                    const value = modifier[key];
                    const index = this.props.modifiers.findIndex((m) => !!m[key]);
                    if (index > -1) {
                        // update existing modifier
                        this.props.modifiers[index][key] = value;
                        this.props.modifiers = [...this.props.modifiers];
                    }
                    else {
                        const newModifier = {};
                        newModifier[key] = value;
                        console.log('value:', value);
                        this.props.modifiers.push(newModifier);
                    }
                }
            }
        }
        this.updateData();
    }
    updateData() {
        this.provider.updateDataWithData(this.props);
    }
}
modifiersProperty.register(SwiftUIViewBase);
//# sourceMappingURL=common.js.map