import { Property, Utils, knownFolders, path } from '@nativescript/core';
import { SwiftUIViewBase } from '../../common';
const srcProperty = new Property({
    name: 'src',
});
const depthProperty = new Property({
    name: 'depth',
    valueConverter: (value) => Number(value),
});
const accessibilitySortPriorityModifier = new Property({
    name: 'accessibilitySortPriority',
    valueConverter: (value) => Number(value),
});
const dragRotationModifier = new Property({
    name: 'dragRotation',
});
export class Model3D extends SwiftUIViewBase {
    constructor() {
        super();
        this.initProps({
            name: null,
            url: null,
            depth: 200,
        });
    }
    createNativeView() {
        // @ts-expect-error
        this.provider = Model3DViewProvider.new();
        return this.provider.view;
    }
    [srcProperty.setNative](value) {
        if (value) {
            if (value.indexOf('http') === 0) {
                this.props.url = value;
            }
            else {
                if (value.indexOf(Utils.RESOURCE_PREFIX) > -1) {
                    value = value.replace(Utils.RESOURCE_PREFIX, '');
                }
                else if (value.indexOf('~/') === 0) {
                    const paths = value.replace('~/', '').split('/');
                    const appFilePath = path.join(knownFolders.currentApp().path, ...paths);
                    console.log('appFilePath:', appFilePath);
                    value = appFilePath;
                }
                this.props.name = value;
            }
            this.updateData();
        }
    }
    [depthProperty.setNative](value) {
        this.props.depth = value;
        this.updateData();
    }
    [dragRotationModifier.setNative](value) {
        this.updateModifiers([
            {
                dragRotation: value,
            },
        ]);
    }
    [accessibilitySortPriorityModifier.setNative](value) {
        this.updateModifiers([
            {
                accessibilitySortPriority: value,
            },
        ]);
    }
}
srcProperty.register(Model3D);
depthProperty.register(Model3D);
dragRotationModifier.register(Model3D);
accessibilitySortPriorityModifier.register(Model3D);
//# sourceMappingURL=index.js.map