import type { ISwiftUIProvider, RegistryCallback } from '.';
import { SwiftUICommon, BaseUIDataDriver, NativeScriptWindowCommon, CustomViewLifeCycle } from './common';
export * from './common';
export * from './components';
export declare function registerSwiftUI(id: string, callback: RegistryCallback): void;
export declare class UIDataDriver extends BaseUIDataDriver<SwiftUI> {
    private swiftUIProvider;
    constructor(swiftUIProvider: ISwiftUIProvider, owner: SwiftUI);
    createNativeView(): UIView;
    registerEvents(callback: any): void;
    updateData(data: any): void;
    onEvent(data: any): void;
}
export declare class SwiftUI extends SwiftUICommon {
    private driver;
    createNativeView(): UIView;
    initNativeView(): void;
    disposeNativeView(): void;
    updateData(data: Record<string, any>): void;
}
export declare class SwiftUIManager {
    /**
     * Register NativeScript Views by id for usage within SwiftUI
     * @param views map of id to NativeScript View
     */
    static registerNativeScriptViews(views: {
        [key: string]: any;
    }, viewLifeCycle?: CustomViewLifeCycle): void;
}
export declare class WindowManager {
    static currentWindows: {
        [key: string]: NativeScriptWindow;
    };
    static getWindow(id: string, isImmersive?: boolean): NativeScriptWindow;
    static supportsMultipleScenes(): boolean;
}
export declare class NativeScriptWindow implements NativeScriptWindowCommon {
    id: string;
    isImmersive?: boolean;
    constructor(id: string, isImmersive?: boolean);
    open(props?: any): Promise<void>;
    close(): Promise<void>;
    update(props?: any): Promise<void>;
    private _updateWindowData;
}
export declare class XR {
    static currentSessionId: string;
    static requestSession(sessionId: string, props?: any): Promise<void>;
    static endSession(): Promise<void>;
}
