import { IOSHelper, LayoutBase, Utils, View, ViewHelper } from '@nativescript/core';
export const UNSPECIFIED = Utils.layout.makeMeasureSpec(0, Utils.layout.UNSPECIFIED);
var ViewLayoutWrapper = /** @class */ (function (_super) {
    __extends(ViewLayoutWrapper, _super);
    function ViewLayoutWrapper() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ViewLayoutWrapper.initWithOwner = function (owner) {
        var view = ViewLayoutWrapper.new();
        view.owner = owner;
        return view;
    };
    Object.defineProperty(ViewLayoutWrapper.prototype, "intrinsicContentSize", {
        // @ts-expect-error when overriding native getters, TypeScript doesn't like it
        get: function () {
            var _a;
            var nsView = (_a = this.owner) === null || _a === void 0 ? void 0 : _a.deref();
            var intrinsicWidth = 0;
            var intrinsicHeight = 0;
            // This will make the view stretch to giant sizes
            // const maxWidth = Screen.mainScreen.widthPixels;
            // const maxHeight = 99999;
            if (nsView) {
                var _b = ViewHelper.measureChild(null, nsView, 
                // Utils.layout.makeMeasureSpec(maxWidth, Utils.layout.AT_MOST),
                // Utils.layout.makeMeasureSpec(maxHeight, Utils.layout.AT_MOST)
                UNSPECIFIED, UNSPECIFIED), measuredWidth = _b.measuredWidth, measuredHeight = _b.measuredHeight;
                intrinsicWidth = Utils.layout.toDeviceIndependentPixels(measuredWidth);
                intrinsicHeight = Utils.layout.toDeviceIndependentPixels(measuredHeight);
            }
            return CGSizeMake(intrinsicWidth || UIViewNoIntrinsicMetric, intrinsicHeight || UIViewNoIntrinsicMetric);
        },
        enumerable: true,
        configurable: true
    });
    ViewLayoutWrapper.prototype.sizeThatFits = function (size) {
        var _a;
        // console.log('sizeThatFits', size);
        var nsView = (_a = this.owner) === null || _a === void 0 ? void 0 : _a.deref();
        if (!nsView) {
            return CGSizeMake(0, 0);
        }
        var _b = ViewHelper.measureChild(null, nsView, Utils.layout.makeMeasureSpec(size.width, Utils.layout.AT_MOST), Utils.layout.makeMeasureSpec(size.height, Utils.layout.AT_MOST)), measuredWidth = _b.measuredWidth, measuredHeight = _b.measuredHeight;
        return CGSizeMake(measuredWidth, measuredHeight);
    };
    return ViewLayoutWrapper;
}(UIView));
export { ViewLayoutWrapper };
var AutoLayoutController = /** @class */ (function (_super) {
    __extends(AutoLayoutController, _super);
    function AutoLayoutController() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AutoLayoutController.initWithOwner = function (owner) {
        var controller = AutoLayoutController.new();
        controller.owner = owner;
        return controller;
    };
    AutoLayoutController.prototype.loadView = function () {
        this.view = ViewLayoutWrapper.initWithOwner(this.owner);
    };
    AutoLayoutController.prototype.viewDidLoad = function () {
        _super.prototype.viewDidLoad.call(this);
        // Unify translucent and opaque bars layout
        this.edgesForExtendedLayout = UIRectEdge.Bottom;
        this.extendedLayoutIncludesOpaqueBars = true;
    };
    // older SDK's
    // public viewWillLayoutSubviews(): void {
    //   super.viewWillLayoutSubviews();
    //   const owner = this.owner.deref();
    //   if (owner) {
    //     IOSHelper.updateConstraints(this, owner);
    //   }
    // }
    AutoLayoutController.prototype.viewDidLayoutSubviews = function () {
        _super.prototype.viewDidLayoutSubviews.call(this);
        var owner = this.owner.deref();
        if (owner) {
            IOSHelper.layoutView(this, owner);
        }
    };
    AutoLayoutController.prototype.viewWillAppear = function (animated) {
        _super.prototype.viewWillAppear.call(this, animated);
        var owner = this.owner.deref();
        if (!owner) {
            return;
        }
        if (!owner.parent) {
            owner.callLoaded();
        }
    };
    AutoLayoutController.prototype.viewDidDisappear = function (animated) {
        _super.prototype.viewDidDisappear.call(this, animated);
        var owner = this.owner.deref();
        if (owner && !owner.parent) {
            owner.callUnloaded();
        }
    };
    // Mind implementation for other controllers
    AutoLayoutController.prototype.traitCollectionDidChange = function (previousTraitCollection) {
        _super.prototype.traitCollectionDidChange.call(this, previousTraitCollection);
        if (Utils.SDK_VERSION >= 13) {
            var owner = this.owner.deref();
            if (owner && this.traitCollection.hasDifferentColorAppearanceComparedToTraitCollection && this.traitCollection.hasDifferentColorAppearanceComparedToTraitCollection(previousTraitCollection)) {
                owner.notify({
                    eventName: IOSHelper.traitCollectionColorAppearanceChangedEvent,
                    object: owner,
                });
            }
        }
    };
    return AutoLayoutController;
}(UIViewController));
export { AutoLayoutController };
/**
 * This view is a proxy wrapper for any other view.
 * It can be used in the future for wrapping more complex views, if needed
 */
export class AutoLayoutView extends LayoutBase {
    _addViewToNativeVisualTree(view, atIndex) {
        const nativeView = this.viewController.view;
        super._addViewToNativeVisualTree(view, atIndex);
        const index = atIndex ?? Infinity;
        if (nativeView && view.nativeViewProtected) {
            if (index >= nativeView.subviews.count) {
                nativeView.addSubview(view.nativeViewProtected);
            }
            else {
                nativeView.insertSubviewAtIndex(view.nativeViewProtected, index);
            }
        }
        return true;
    }
    _removeViewFromNativeVisualTree(view) {
        const nativeView = this.viewController.view;
        super._removeViewFromNativeVisualTree(view);
        if (view.nativeViewProtected) {
            if (view.nativeViewProtected.superview === nativeView) {
                view.nativeViewProtected.removeFromSuperview();
            }
        }
    }
    createNativeView() {
        this.viewController = AutoLayoutController.initWithOwner(new WeakRef(this));
        this.viewController.view.translatesAutoresizingMaskIntoConstraints = true;
        return this.viewController.view;
    }
    layoutNativeView() {
        // noop
    }
    _setNativeViewFrame() {
        // noop
    }
    onMeasure(widthMeasureSpec, heightMeasureSpec) {
        const width = Utils.layout.getMeasureSpecSize(widthMeasureSpec);
        const widthMode = Utils.layout.getMeasureSpecMode(widthMeasureSpec);
        const height = Utils.layout.getMeasureSpecSize(heightMeasureSpec);
        const heightMode = Utils.layout.getMeasureSpecMode(heightMeasureSpec);
        let measureWidth = this.effectiveMinWidth;
        let measureHeight = this.effectiveMinHeight;
        this.eachLayoutChild((child) => {
            const result = View.measureChild(this, child, widthMeasureSpec, heightMeasureSpec);
            measureWidth = Math.max(result.measuredWidth, measureWidth);
            measureHeight = Math.max(result.measuredHeight, measureHeight);
            return true;
        });
        const widthAndState = View.resolveSizeAndState(measureWidth, width, widthMode, 0);
        const heightAndState = View.resolveSizeAndState(measureHeight, height, heightMode, 0);
        this.setMeasuredDimension(widthAndState, heightAndState);
    }
    // This method won't be called in Android because we use the native android layout.
    onLayout(left, top, right, bottom) {
        this.eachLayoutChild((child) => {
            View.layoutChild(this, child, 0, 0, right - left, bottom - top);
            return true;
        });
    }
}
//# sourceMappingURL=view-helper-controllers.ios.js.map